@@ -3,7 +3,7 @@
  *   Copyright 1997  Mario Weilguni <mweilguni@sime.com>                   *
  *   Copyright 2002-2004  Dave Corrie <kde@davecorrie.com>                 *
  *   Copyright 2007  Mauricio Piacentini <mauricio@tabuleiro.com>          *
- *   Copyright 2009-2011  Frederik Schwarzer <schwarzer@kde.org>           *
+ *   Copyright 2009-2016  Frederik Schwarzer <schwarzer@kde.org>           *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -27,6 +27,7 @@
 
 // Qt
 #include <QIcon>
+#include <QLabel>
 #include <QPointer>
 #include <QStatusBar>
 #include <QTimer>
@@ -48,7 +49,7 @@
 #include <KScoreDialog>
 #include <KStandardGameAction>
 
-// Kmahjongg
+// LibKmahjongg
 #include <kmahjonggconfigdialog.h>
 
 // KShisen
@@ -57,7 +58,8 @@
 #include "prefs.h"
 #include "ui_settings.h"
 
-
+namespace KShisen
+{
 /**
  * @brief Class holding the settings dialog and its functions
  */
@@ -123,7 +125,7 @@ void App::setupActions()
     KStandardGameAction::redo(this, SLOT(redo()), actionCollection());
     KStandardGameAction::hint(this, SLOT(hint()), actionCollection());
 
-    KToggleAction * soundAction = new KToggleAction(QIcon::fromTheme(QStringLiteral("speaker")), i18n("Play Sounds"), this);
+    auto soundAction = new KToggleAction(QIcon::fromTheme(QStringLiteral("speaker")), i18n("Play Sounds"), this);
     soundAction->setChecked(Prefs::sounds());
     actionCollection()->addAction(QStringLiteral("sounds"), soundAction);
     connect(soundAction, &KToggleAction::triggered, m_board, &Board::setSoundsEnabled);
@@ -253,10 +255,10 @@ void App::slotEndOfGame()
         m_board->setGameStuckEnabled(true);
     } else {
         m_board->setGameOverEnabled(true);
-        QString const timeString = i18nc("time string: hh:mm:ss", "%1:%2:%3",
-                                         QString().sprintf("%02d", m_board->currentTime() / 3600),
-                                         QString().sprintf("%02d", (m_board->currentTime() / 60) % 60),
-                                         QString().sprintf("%02d", m_board->currentTime() % 60));
+        auto const timeString = i18nc("time string: hh:mm:ss", "%1:%2:%3",
+                                      QString().sprintf("%02d", m_board->currentTime() / 3600),
+                                      QString().sprintf("%02d", (m_board->currentTime() / 60) % 60),
+                                      QString().sprintf("%02d", m_board->currentTime() % 60));
         KScoreDialog::FieldInfo scoreInfo;
         scoreInfo[KScoreDialog::Score].setNum(score(m_board->xTiles(), m_board->yTiles(), m_board->currentTime(), m_board->gravityFlag()));
         scoreInfo[KScoreDialog::Time] = timeString;
@@ -269,19 +271,19 @@ void App::slotEndOfGame()
         } else {
             scoreInfo[KScoreDialog::Custom1] = i18n("No");
         }
-        QString const configGroup = QStringLiteral("%1x%2").arg(m_board->xTiles()).arg(m_board->yTiles());
+        auto const configGroup = QStringLiteral("%1x%2").arg(m_board->xTiles()).arg(m_board->yTiles());
         scoreDialog->setConfigGroup(qMakePair(QByteArray(configGroup.toUtf8()), configGroup));
 
         if (m_board->hasCheated()) {
-            QString const message = i18n("\nYou could have been in the highscores\nif you did not use Undo or Hint.\nTry without them next time.");
+            auto const message = i18n("\nYou could have been in the highscores\nif you did not use Undo or Hint.\nTry without them next time.");
             KMessageBox::information(this, message, i18n("End of Game"));
         } else {
             if (scoreDialog->addScore(scoreInfo) > 0) {
-                QString const message = i18n("Congratulations!\nYou made it into the hall of fame.");
+                auto const message = i18n("Congratulations!\nYou made it into the hall of fame.");
                 scoreDialog->setComment(message);
                 scoreDialog->exec();
             } else {
-                QString const message = i18nc("%1 - time string like hh:mm:ss", "You made it in %1", timeString);
+                auto const message = i18nc("%1 - time string like hh:mm:ss", "You made it in %1", timeString);
                 KMessageBox::information(this, message, i18n("End of Game"));
             }
         }
@@ -295,20 +297,20 @@ void App::updateTimeDisplay()
     if (m_board->isStuck() || m_board->isOver()) {
         return;
     }
-    //qCDebug(KSHISEN_LOG) << "Time: " << m_board->currentTime();
-    int const currentTime = m_board->currentTime();
-    QString const message = i18n("Your time: %1:%2:%3 %4",
-                                 QString().sprintf("%02d", currentTime / 3600),
-                                 QString().sprintf("%02d", (currentTime / 60) % 60),
-                                 QString().sprintf("%02d", currentTime % 60),
-                                 m_board->isPaused() ? i18n("(Paused) ") : QString());
+    //qCDebug(KSHISEN_General) << "Time: " << m_board->currentTime();
+    auto const currentTime = m_board->currentTime();
+    auto const message = i18n("Your time: %1:%2:%3 %4",
+                              QString().sprintf("%02d", currentTime / 3600),
+                              QString().sprintf("%02d", (currentTime / 60) % 60),
+                              QString().sprintf("%02d", currentTime % 60),
+                              m_board->isPaused() ? i18n("(Paused) ") : QString());
 
     m_gameTimerLabel->setText(message);
 }
 
 void App::updateTileDisplay()
 {
-    int const numberOfTiles = m_board->tiles();
+    auto const numberOfTiles = m_board->tiles();
     m_gameTilesLabel->setText(i18n("Removed: %1/%2 ", numberOfTiles - m_board->tilesLeft(), numberOfTiles));
 }
 
@@ -319,11 +321,11 @@ void App::updateCheatDisplay()
 
 int App::score(int x, int y, int seconds, bool gravity) const
 {
-    double const ntiles = x * y;
-    double const tilespersec = ntiles / static_cast<double>(seconds);
+    auto const ntiles = static_cast<double>(x * y);
+    auto const tilespersec = ntiles / static_cast<double>(seconds);
 
-    double const sizebonus = std::sqrt(ntiles / static_cast<double>(14.0 * 6.0));
-    double const points = tilespersec / 0.14 * 100.0;
+    auto const sizebonus = std::sqrt(ntiles / static_cast<double>(14.0 * 6.0));
+    auto const points = tilespersec / 0.14 * 100.0;
 
     if (gravity) {
         return static_cast<int>(2.0 * points * sizebonus);
@@ -366,7 +368,7 @@ void App::showHighscores()
 {
     KScoreDialog scoreDialog(KScoreDialog::Name | KScoreDialog::Time, this);
     scoreDialog.addField(KScoreDialog::Custom1, i18n("Gravity"), QStringLiteral("gravity"));
-    QString const configGroup = QStringLiteral("%1x%2").arg(m_board->xTiles()).arg(m_board->yTiles());
+    auto const configGroup = QStringLiteral("%1x%2").arg(m_board->xTiles()).arg(m_board->yTiles());
     scoreDialog.setConfigGroup(qMakePair(QByteArray(configGroup.toUtf8()), configGroup));
     scoreDialog.exec();
 }
@@ -383,7 +385,7 @@ void App::showSettingsDialog()
     }
 
     //Use the classes exposed by LibKmahjongg for our configuration dialog
-    KMahjonggConfigDialog * dialog = new KMahjonggConfigDialog(this, QStringLiteral("settings"), Prefs::self());
+    auto dialog = new KMahjonggConfigDialog(this, QStringLiteral("settings"), Prefs::self());
     dialog->addPage(new Settings(nullptr), i18n("General"), QStringLiteral("games-config-options"));
     dialog->addTilesetPage();
     dialog->addBackgroundPage();
@@ -391,6 +393,7 @@ void App::showSettingsDialog()
     connect(dialog, &KMahjonggConfigDialog::settingsChanged, m_board, &Board::loadSettings);
     dialog->show();
 }
+} // namespace KShisen
 
 // vim: expandtab:tabstop=4:shiftwidth=4
 // kate: space-indent on; indent-width 4
